Module native

Module native 

Functions

decode_field_to_addr
decode_hilo_to_h256
decode_hilo_to_u256
encode_addr_to_field
encode_h256_to_hilo
Takes hash as bytes32 and returns (hash[..16], hash[16..]) represented as big endian numbers in the prime field
encode_u256_to_hilo
Takes U256, converts to bytes32 (big endian) and returns (hash[..16], hash[16..]) represented as big endian numbers in the prime field
u256_to_h256